@@ -42,8 +42,11 @@ noparams <- lapply(unit_objects(ppo),pomp,params=numeric(0))
 
 ep <- "Error : in ''panelPomp'': "
 ## test checks for missing arguments in panelPomp function
-test(wQuotes(ep,"''object'' is a required argument.\n"),
-     panelPomp())
+test(
+  wQuotes(ep, "''object'' is a required argument.\n"),
+  panelPomp()
+)
+
 test(wQuotes(ep,"''object'' must be either a ''panelPomp'' object or a list of",
              " ''pomp'' objects.","\n"),
      panelPomp(list(a=1)))
